pub enum GeneratorError {
InputNotFound(String),
OutputNotFound(String),
ShapeMismatch(String),
GenerateError(Box<dyn Error>),
DecodeError(TokenizerError),
}Expand description
Errors that occur when creating or running a Generator.
Variants
InputNotFound(String)
An expected model input was not found.
OutputNotFound(String)
An expected model output was not found.
ShapeMismatch(String)
An input or output did not have the expected shape.
GenerateError(Box<dyn Error>)
An error occurred while generating the next token.
DecodeError(TokenizerError)
An error occurred while decoding tokens.