pub struct Multinomial { /* private fields */ }Expand description
A Sampler which chooses a token ID according to the probability of each
logit.
Input logits are first normalized using a softmax operation before a token ID is sampled according to the probability of each logit.
By default sampling uses a random seed so results will vary for each run.
To get repeatable sampling, use with_seed.
Implementations